Quick start guide — django-comments-xtd 2.0.10 documentation

# Quick start guide

To get started using django-comments-xtd follow these steps:

1. `pip install django-comments-xtd`

2. Enable the “sites” framework by adding `'django.contrib.sites'` to `INSTALLED_APPS` and defining `SITE_ID`. Visit the admin site and be sure that the domain field of the `Site` instance points to the correct domain (`localhost:8000` when running the default development server), as it will be used to create comment verification URLs, follow-up cancellations, etc.

3. Add `'django_comments_xtd'` and `'django_comments'`, in that order, to `INSTALLED_APPS`.

4. Set the `COMMENTS_APP` setting to `'django_comments_xtd'`.

5. Set the `COMMENTS_XTD_MAX_THREAD_LEVEL` to `N`, being `N` the maximum level of threading up to which comments will be nested in your project.

       # 0: No nested comments:
       #  Comment (level 0)
       # 1: Nested up to level one:
       #  Comment (level 0)
       #   |-- Comment (level 1)
       # 2: Nested up to level two:
       #  Comment (level 0)
       #   |-- Comment (level 1)
       #        |-- Comment (level 2)
       COMMENTS_XTD_MAX_THREAD_LEVEL = 2

   The thread level can also be established on a per `<app>.<model>` basis by using the `COMMENTS_XTD_MAX_THREAD_LEVEL_BY_APP_MODEL` setting. Use it to establish different maximum threading levels for each model. ie: no nested comments for quotes, up to thread level 2 for blog stories, etc.

6. Set the `COMMENTS_XTD_CONFIRM_EMAIL` to `True` to require comment confirmation by email for no logged-in users.

7. Run `manage.py migrate` to create the tables.

8. Add the URLs of the comments-xtd app to your project’s `urls.py`:

       urlpatterns = [
           ...
           url(r'^comments/', include('django_comments_xtd.urls')),
           ...
       ]

9. Customize your project’s email settings:

       EMAIL_HOST = "smtp.mail.com"
       EMAIL_PORT = "587"
       EMAIL_HOST_USER = "alias@mail.com"
       EMAIL_HOST_PASSWORD = "yourpassword"
       DEFAULT_FROM_EMAIL = "Helpdesk <helpdesk@yourdomain>"

10. As of version 1.7.1 django-comments-xtd comes with templates styled with twitter-bootstrap v3 to allow a quick start. If you want to build your own templates, use the comments templatetag module, provided by the django-comments app. Create a `comments` directory in your templates directory and copy the templates you want to customise from the Django Comments Framework. The following are the most important:

    - `comments/list.html`, used by the `render_comments_list` templatetag.
    - `comments/form.html`, used by the `render_comment_form` templatetag.
    - `comments/preview.html`, used to preview the comment or when there are errors submitting it.
    - `comments/posted.html`, which gets rendered after the comment is sent.

11. Add extra settings to control comments in your project. Check the available settings in the Django Comments Framework and in the django-comments-xtd app.

These are the steps to quickly start using django-comments-xtd. Follow to the next page, the Tutorial, to read a detailed guide that takes everything into account. In addition to the tutorial, the Demo projects implement several commenting applications.